Coverage for src/auth/api/__init__.py: 100%

1 from litestar import Router

2

3 from .account_controller import AccountController

4 from .permission_controller import PermissionController

5 from .role_controller import RoleController

6 from .user_controller import UserController

7

8 auth_router = Router(

9 path="/api/auth",

10 route_handlers=[

11 UserController,

12 RoleController,

13 PermissionController,

14 AccountController,

15 ],

16)

17

18 __all__ = ["auth_router"]